#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-BUaY8w5PQ7sCy82HJusOja
key:                  should-not-typecheck-2.1.0-BUaY8w5PQ7sCy82HJusOja
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  724d1c29592f82943c450f07c97f78c6
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-BUaY8w5PQ7sCy82HJusOja
depends:
    HUnit-1.6.2.0-L1r9G4r6Tqe7YoPeBDc5p3 base-4.18.2.1 deepseq-1.4.8.1

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

